\name{myshow-methods}
\docType{methods}
\alias{myshow-methods}
\alias{myshow,ANY-method}
\alias{myshow,Seq-method}
\title{~~ Dummy title ~~}
\description{~~ Dummy description ~~}
\section{Methods}{
\describe{

\item{\code{signature(object = "ANY")}}{
%%  ~~describe this method here~~
}

\item{\code{signature(object = "Seq")}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
