\name{set_Rdpack_bibstyle}
\alias{set_Rdpack_bibstyle}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Set up a bibstyle defined in Rdpack}
\description{Set up a bibstyle defined in Rdpack}
\usage{
set_Rdpack_bibstyle(bibstyle = "JSSRd")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{bibstyle}{a character string}
}
%\details{
%%%  ~~ If necessary, more details than the description above ~~
%}
%\value{
%%%  ~Describe the value returned
%%%  If it is a LIST, use
%%%  \item{comp1 }{Description of 'comp1'}
%%%  \item{comp2 }{Description of 'comp2'}
%%% ...
%}
%\references{
%%% ~put references to the literature/web site here ~
%}
%\author{
%%%  ~~who you are~~
%}
%\note{
%%%  ~~further notes~~
%}
%
%%% ~Make other sections like Warning with \section{Warning }{....} ~
%
%\seealso{
%%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
%\examples{
%}
\keyword{internal}
